#!/bin/sh
echo 'name: lens
version: 3.9.0.2
id: lens-3.9.0.2-cb79dfdfb33b6e84ed0c389735691f39

license: BSD3
copyright: Copyright (C) 2012-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/lens/
package-url:
synopsis: Lenses, Folds and Traversals
description: This package comes \"Batteries Included\" with many useful lenses for the types
             commonly used from the Haskell Platform, and with tools for automatically
             generating lenses and isomorphisms for user-supplied data types.
             .
             The combinators in @Control.Lens@ provide a highly generic toolbox for composing
             families of getters, folds, isomorphisms, traversals, setters and lenses and their
             indexed variants.
             .
             An overview, with a large number of examples can be found in the @README@: <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals>
             .
             A video on how to use lenses and how they are constructed is available from youtube: <http://youtu.be/cefnmjtAolY?hd=1>
             .
             Slides can be obtained here: <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf>
             .
             More information on the care and feeding of lenses, including a brief tutorial and motivation
             for their types can be found on the lens wiki: <https://github.com/ekmett/lens/wiki>
             .
             A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the example folder: <https://github.com/ekmett/lens/blob/master/examples/>
             .
             /Lenses, Folds and Traversals/
             .
             The core of the hierarchy of lens-like constructions looks like:
             .
             .
             <<http://i.imgur.com/4fHw3Fd.png>>
             .
             Local copy (<Hierarchy.png>)
             .
             You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
             use any element of the hierarchy as any type it linked to above it.
             .
             The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
             .
             For instance:
             .
             * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
             .
             * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
             .
             /Minimizing Dependencies/
             .
             If you want to provide lenses and traversals for your own types in your own libraries, then you
             can do so without incurring a dependency on this (or any other) lens package at all.
             .
             /e.g./ for a data type:
             .
             > data Foo a = Foo Int Int a
             .
             You can define lenses such as
             .
             > -- bar :: Lens'\'' (Foo a) Int
             > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
             > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
             .
             > -- baz :: Lens (Foo a) (Foo b) a b
             > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
             > quux f (Foo a b c) = fmap (Foo a b) (f c)
             .
             without the need to use any type that isn'\''t already defined in the @Prelude@.
             .
             And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
             .
             > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
             > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
             > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
             .
             What is provided in this library is a number of stock lenses and traversals for
             common haskell types, a wide array of combinators for working them, and more
             exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses
author: Edward A. Kmett
exposed: True
exposed-modules: Control.Exception.Lens Control.Lens
                 Control.Lens.Action Control.Lens.At Control.Lens.Combinators
                 Control.Lens.Cons Control.Lens.Each Control.Lens.Equality
                 Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
                 Control.Lens.Internal Control.Lens.Internal.Action
                 Control.Lens.Internal.Bazaar Control.Lens.Internal.ByteString
                 Control.Lens.Internal.Context Control.Lens.Internal.Deque
                 Control.Lens.Internal.Exception Control.Lens.Internal.Fold
                 Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
                 Control.Lens.Internal.Instances Control.Lens.Internal.Iso
                 Control.Lens.Internal.Level Control.Lens.Internal.Magma
                 Control.Lens.Internal.Prism Control.Lens.Internal.Review
                 Control.Lens.Internal.Setter Control.Lens.Internal.Zipper
                 Control.Lens.Internal.Zoom Control.Lens.Iso Control.Lens.Lens
                 Control.Lens.Level Control.Lens.Loupe Control.Lens.Operators
                 Control.Lens.Plated Control.Lens.Prism Control.Lens.Reified
                 Control.Lens.Review Control.Lens.Setter Control.Lens.Simple
                 Control.Lens.TH Control.Lens.Traversal Control.Lens.Tuple
                 Control.Lens.Type Control.Lens.Wrapped Control.Lens.Zipper
                 Control.Lens.Zoom Control.Monad.Error.Lens
                 Control.Parallel.Strategies.Lens Control.Seq.Lens Data.Array.Lens
                 Data.Bits.Lens Data.ByteString.Lens Data.ByteString.Strict.Lens
                 Data.ByteString.Lazy.Lens Data.Complex.Lens Data.Data.Lens
                 Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
                 Data.List.Split.Lens Data.Sequence.Lens Data.Set.Lens
                 Data.Text.Lens Data.Text.Strict.Lens Data.Text.Lazy.Lens
                 Data.Tree.Lens Data.Typeable.Lens Data.Vector.Lens
                 Data.Vector.Generic.Lens Generics.Deriving.Lens GHC.Generics.Lens
                 System.Exit.Lens System.FilePath.Lens System.IO.Error.Lens
                 Language.Haskell.TH.Lens Numeric.Lens
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/lens-3.9.0.2
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/lens-3.9.0.2
              /usr/local/lib
hs-libraries: HSlens-3.9.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: MonadCatchIO-transformers-0.3.0.0-00f5ba39422294066c7f13d4ef6c89a7
         array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
         base-4.6.0.1-f7bdc8987bd5928e0ee6e8cc8b246a88
         bifunctors-3.2.0.1-eb9f4da7e887fac9731126d77722e13a
         bytestring-0.10.0.2-59abd9894532f476aabac207680aae43
         comonad-3.0.2-27f71bc8afec8cf027680909261903d1
         comonad-transformers-3.0.2-d0caea6026cdcc194f1084052565ad89
         comonads-fd-3.0.1-121a2ad600c8f9b827b01f4534d13849
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
         contravariant-0.4-282f6ade8d0dee999b832622ff101e87
         distributive-0.3.1-9cd9a1cf5f4409181a607243a8c42721
         filepath-1.3.0.1-b12cbe18566fe1532a1fda4c85e31cbe
         generic-deriving-1.5.0-34603698a2f95701dd95bc87a1175ce9
         ghc-prim-0.3.0.0-d5221a8c8a269b66ab9a07bdc23317dd
         hashable-1.1.2.5-e0f2541518f84d3123a819112b4ffe20
         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
         parallel-3.2.0.3-d6c020cb3aa15c71f5f29c0db359fd39
         profunctor-extras-3.3-106247b06483475b1d5d6bf68bd26ad0
         profunctors-3.3.0.1-61f02bca7a5a9a579cff551c2ccf4d00
         reflection-1.3.2-ea74ee2300447d3341ce4b5d753c72b6
         semigroupoids-3.0.2-88cd5e67ac3e0dbaa9b60dee43cad4af
         semigroups-0.9.1-648e60f9128f19cd38e9ac6cf50a7001
         split-0.2.2-9ce33138f4fcfb9c37f6e6c300bcc367
         tagged-0.6-ceec0c47465ccecc078b0c051fef0f5a
         template-haskell-2.8.0.0-91c2562cc83a7f46e2e06b8769919b9d
         text-0.11.3.1-b49365bcfaf3954e4484c36c86c98126
         transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
         unordered-containers-0.2.3.1-a104e98659198f3079fae6376d376e49
         vector-0.10.0.1-869166d5d49db46ce6c328ea5f8defbf
         void-0.6-085941cdab66cf1cbc46df01b2f33577
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/lens-3.9.0.2/html/lens.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/lens-3.9.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
